@@ -25,6 +25,7 @@ sub _ref {
 # main layout, main frame
 sub splashscreen {
 	Wx::InitAllImageHandlers();
+	my $img = Kephra::Config::filepath( $Kephra::temp{file}{img}{splashscreen} );
 	Wx::SplashScreen->new(
 		Wx::Bitmap->new(
 			Kephra::Config::filepath( $Kephra::temp{file}{img}{splashscreen} ),
@@ -33,60 +34,7 @@ sub splashscreen {
 		wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_TIMEOUT, 150, undef, -1,
 		wxDefaultPosition, wxDefaultSize,
 		wxSIMPLE_BORDER | wxFRAME_NO_TASKBAR | wxSTAY_ON_TOP
-	);
-}
-
-sub setup_logging {
-    eval {
-        require Log::Dispatch;
-        require Log::Dispatch::File;
-    };
-    if ($@) {
-        _setup_fake_logger();
-    } else {
-        _setup_real_logger();
-    }
-    $main::logger->info("Starting");
-    return;
-}
-
-sub _setup_fake_logger {
-    package Kephra::FakeLogger;
-    $main::logger = bless {}, __PACKAGE__; 
-    no strict 'refs';
-    foreach my $l ( qw( debug info notice warning err error crit critical alert emerg emergency ) )
-    {
-        *{$l} = sub {};
-    }
-    return;
-}
-
-sub _setup_real_logger {
-    mkdir $Kephra::temp{path}{logger};
-    # TODO: setup pseudo logger in case the directory does not exist or
-    # otherwise cannot start the logger, report error
-    $main::logger = Log::Dispatch->new;
-    require POSIX;
-    my $ts = POSIX::strftime("%Y%m%d", localtime);
-            print File::Spec->catfile($Kephra::temp{path}{logger}, "$ts.log");
-    $main::logger->add( Log::Dispatch::File->new( 
-            name        => 'file1',
-            min_level   => ($ENV{KEPHRA_LOGGIN} || 'debug'),
-            filename    => File::Spec->catfile($Kephra::temp{path}{logger}, "$ts.log"),
-            mode        => 'append',
-            callbacks   => \&_logger,
-    ));
-    $SIG{__WARN__} = sub { $main::logger->warning($_[0]) };
-    return;
-}
-
-
-sub _logger {
-    my %data = @_;
-    # TODO maybe we should use regular timestamp here and turn on the hires timestamp
-    # only if KEPHRA_TIME or similar env variable is set
-    require Time::HiRes;
-    return sprintf("%s - %s - %s - %s\n", Time::HiRes::time(), $$, $data{level}, $data{message});
+	) if $img and -e $img;
 }
 
 
@@ -181,8 +129,9 @@ sub start {
 	_ref($app);
 	Kephra::Config::init();
 	#setup_logging();
-	splashscreen();             # 2'nd splashscreen can close when app is ready
 	Wx::InitAllImageHandlers();
+	splashscreen();             # 2'nd splashscreen can close when app is ready
+	Kephra::API::EventTable::init();
 	my $frame = Kephra::App::Window::create();
 	my $ep = Kephra::App::EditPanel::create();
 	$Kephra::temp{document}{open}[0]{pointer} = $ep->GetDocPointer();
